@@ -2,11 +2,12 @@ __title__ = 'tkt-Toolkit'
 __author__ = 'Suprime'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2020-2021 Suprime'
-__version__ = '1.7'
+__version__ = '1.8.2'
 
-import time,socket,json,os
-from . import TTA,Crypto,SpeechRecongition,texttospeech,translator,Youtube,Discord_framework,parse,tracking
+import time,socket,json,os,piexif.helper
+from . import TTA,Crypto,SpeechRecongition,texttospeech,translator, parse,tracking
 from .errors import *
+from win32com.client import Dispatch
 
 here = os.path.dirname(os.path.abspath(__file__))
 
@@ -21,57 +22,68 @@ class SpeechRecognition:
     Records or reads audio and transforms it to text.
     Can also list Microphones.
     """
-    def from_Microphone(show_msg: bool = True):
-        return SpeechRecongition.recon.recon_from_mic(show_msg)
-    def from_Wav_File(wav_file: str, show_msg: bool = True):
+    def __init__(self,show_msg:bool=True):
+        self.show_msg = show_msg
+    def from_Microphone(self):
+        return SpeechRecongition.recon.recon_from_mic(self.show_msg)
+    def from_Wav_File(self,wav_file: str, show_msg: bool = True):
         open(wav_file)
         return SpeechRecongition.recon.recon_from_file(wav_file, show_msg)
-    def list_Microphones(detailed: bool = True):
-        for EE in SpeechRecongition.recon.get_mics(detailed): yield EE
-
-class Info:
-    def __version__(self=""):return __version__
-    def __copyright__(self=""):return __copyright__
-    def __license__(self=""):return __license__
-    def __author__(self=""):return __author__
+    def list_Microphones(self):
+        for EE in SpeechRecongition.recon.get_mics(self.show_msg): yield EE
 
 class Toolkit:
+    def __init__(self):
+        self.active = True
+        self.version = __version__
     class Crypto:
         """
         Uses the cryptography package and xor to
         encrypt/decrypt 'Text'. Encrypt returns a tuple
         """
-        def encrypt(Text:bytes):
+        def __init__(self):
+            self.active = True
+            self.version = "1.1"
+        def encrypt(self,Text:bytes):
             return Crypto.crypto.encrypt(Text)
-        def decrypt(Text:bytes,Key:bytes):
+        def decrypt(self,Text:bytes,Key:bytes):
             return Crypto.crypto.decrypt(Key,Text)
-    def del_all(dir : str,log:bool=True):
+    def del_all(self,dir : str,log:bool=True):
         """
         Clears the folders and then deletes
         them, using os.listdir,os.remove,os.rmdir
         """
         parse.using.del_files(dir,log)
         parse.using.del_folders(dir,log)
-    def getip(S=""):
+        return None
+    def getip(self):
         """
         Gets the users IP using the python
         built-in socket package.
         """
         return socket.gethostbyname(socket.gethostname())
-    def texttospeech(Content:str, Lang:str, Axc:str="com",using_dir:str=''):
+    def texttospeech(self,Content:str, Lang:str, Axc:str="com",using_dir:str=''):
         """
         Creates a file in the 'using_dir' and
         plays it.
         """
         texttospeech.tts(Content,Axc,Lang,using_dir)
-    def translate(Text:str,Dest,From='auto'):
+        return None
+    def translate(self,Text:str,Dest,From='auto'):
         """
         Translate 'Text' from 'From' to 'Dest',
         set 'Dest' to "auto" if you don't know
         the language.
+
+        Returns 2 values:
+        1 : Translated Text
+        2 : Tuple:
+            1 : Text Language
+            2 : Translated Language
+            3 : Text
         """
         return translator.Translate(Text,Dest,From)
-    def weather(city:str, key:str):
+    def weather(self,city:str, key:str):
         """
         Gets the weather from openweathermap.org,
         uses the standard free to use api.
@@ -82,7 +94,7 @@ class Toolkit:
         response = parse.x.get(url).text
         data = json.loads(response)
         return data
-    def get_color(rgb: tuple = None, hex: str = None):
+    def get_color(self,rgb: tuple = None, hex: str = None):
         """
         Gets the color-data of one 'hex'/'rgb' color
         """
@@ -94,22 +106,27 @@ class Toolkit:
             R = 1
         elif rgb == None and not hex == None:
             R = 2
+        else:
+            raise InternalError
         if R == 1:
             req = parse.Q.build_main + parse.Q.build_rgb + str(rgb)
         elif R == 2:
             req = parse.Q.build_main + parse.Q.build_hex + str(hex.replace('#', '', 1))
+        else:
+            raise InternalError
         resp = (parse.x.get(req).text)
         return parse.using.pull_values(resp)
-    def calc(calc):
+    def calc(self,calc):
         exec(f'global __COMP_CALC_END__\n__COMP_CALC_END__=({calc})')
         return __COMP_CALC_END__
-    def do_for(n_seconds: int, func):
+    def do_for(self,n_seconds: int, func):
         """
         Runs 'func' for 'n_seconds'
         """
         t_end = time.time() + n_seconds
         while time.time() < t_end: func()
-    def is_URLsafe(string: str, allowSub: bool = False):
+        return None
+    def is_URLsafe(self,string: str, allowSub: bool = False):
         """
         Checks if 'string' is URL-safe, enable
         'allowSub' to not affect "/" characters.
@@ -119,15 +136,30 @@ class Toolkit:
         if not allowSub:
             if "/" in string: return False
         return True
-    def make_URLsafe(string: str, allowSub: bool = False, replaceChar: str = "-"):
-        """
-        Replaces the not URL-safe charachters in 'string' with
-        'replaceChar', enable 'allowSub' to not affect "/" characters.
-        """
-        e = string
-        for i in parse.Q.urlSafeChars:
-            erg = e.replace(i, replaceChar)
-            e = erg
-        if not allowSub: e = e.replace("/", replaceChar)
-        return e
+    def read_metadata(self,filename:str):
+        exif_dict = piexif.load(filename)
+        user_comment = piexif.helper.UserComment.load(exif_dict["Exif"][piexif.ExifIFD.UserComment])
+        d = json.loads(user_comment)
+        return d
+    def write_metadata(self,filename:str,json_data:str):
+        exif_dict = piexif.load(filename)
+        exif_dict["Exif"][piexif.ExifIFD.UserComment] = piexif.helper.UserComment.dump(
+            json.dumps(json_data),
+            encoding="unicode"
+        )
+        piexif.insert(
+            piexif.dump(exif_dict),
+            filename
+        )
+        return None
+    def create_shortcut(self,target:str,output:str):
+        path = output
+        shell = Dispatch('WScript.Shell')
+        shortcut = shell.CreateShortCut(path)
+        shortcut.Targetpath = target
+        shortcut.WorkingDirectory = target
+        shortcut.IconLocation = target
+        shortcut.save()
+        return None
+
 tkt=Toolkit
\ No newline at end of file
