@@ -14,5 +14,11 @@ class NotImplemented(Exception):
     def __init__(self,Note:str=""):
         pass
 class NotActivated(Exception):
+    def __init__(self,Note:str=""):
+        pass
+class InvalidAuth(Exception):
+    def __init__(self,Note:str=""):
+        pass
+class NonExsistant(Exception):
     def __init__(self,Note:str=""):
         pass
\ No newline at end of file
