@@ -1,7 +1,8 @@
+import termcolor
 import cv2,mediapipe,time,keyboard,numpy
 import pytesseract.pytesseract
-import tesseract_pack
-from .parse import *
+from pyzbar.pyzbar import decode as qr_decode_dat
+from .parse import Hand,Pose,Face,FaceMesh,ScannedText,qr
 class Utils:
     def absa(c1:tuple,c2:tuple,t:int):
         """
@@ -50,6 +51,9 @@ class HandDetector:
                 List = []
                 for id, lm in enumerate(handLms.landmark):
                     h, w, c = img.shape
+                    global _COMP_y_cord
+                    _COMP_y_cord = lm.z
+                    print(_COMP_y_cord)
                     cx, cy = int(lm.x * w), int(lm.y * h)
                     List.append((cx,cy))
                 yield Hand(HAND,List,handLms)
@@ -90,7 +94,7 @@ class PoseDetector:
             if wd:
                 for id, lm in enumerate(res.landmark):
                     h, w, c = img.shape
-                    cx, cy = int(lm.x * w), int(lm.y * h)        # I have not tested the two person option, bcuz i have no friends
+                    cx, cy = int(lm.x * w), int(lm.y * h)
                     List.append((cx,cy))
                 try:
                     yield Pose(List, res)
@@ -253,7 +257,16 @@ class Segmentation:
             imgOut = numpy.where(condition, img, self.replace_img) # Combine both
         return imgOut
 class TextRecognition:
-    def __init__(self,img):
+    def __init__(self,img,tesseract_dir:str=None):
+        if not tesseract_dir:
+            try:
+                import tesseract_pack
+                self.dat_here = tesseract_pack.data_here
+            except ModuleNotFoundError:
+                print(termcolor.colored('tesseract-ocr is needed for TextRecognition, install "tesseract-ocr-data" or specify "tesseract_dir"'))
+                return
+        else:
+            self.dat_here = tesseract_dir
         self.def_img = img
         self.IMG = cv2.cvtColor(img,cv2.COLOR_BGR2RGB)
         self.shape = self.IMG.shape
@@ -261,7 +274,7 @@ class TextRecognition:
         self.hIMG = tmp_hIMG
         self.wIMG =tmp_wImg
         tox = '\\'
-        self.install = (f'{tesseract_pack.data_here.replace(tox,"/")}\\tesseract.exe') # tesseract_pack.data_here is the location of tesseract, it is used, so it does not have to be installed manually
+        self.install = (f'{self.dat_here.replace(tox,"/")}\\tesseract.exe')
     def get_data(self):
         pytesseract.pytesseract.tesseract_cmd = self.install
         result1 = pytesseract.pytesseract.image_to_boxes(self.IMG)
@@ -273,6 +286,21 @@ class TextRecognition:
         for b in obj.boxes:
             cv2.rectangle(img,(b[0],obj.height-b[1]),(b[2],obj.height-b[3]),(0,0,255),3)
         return img
+class qrbar_code:
+    def __init__(self,img):
+        self.raw_ = qr_decode_dat(img)
+        if not self.raw_ == []:
+            self.object = qr(img,self.raw_)
+        else:
+            self.object = None
+    def get_text(self):
+        if self.object == None:return
+        obj : qr = self.object
+        return obj.decoded_txt
+    def get_all_data(self):
+        if self.object == None: return
+        obj: qr = self.object
+        return obj
 class Examples:
     def SPS(input=1,quit_key='esc'):
         """
